--[[
MillHelp
Author: Michael Joseph Murray aka Starinnia of Lothar(US) aka Lyte of Lothar(US)
Please see license.txt for details.
$Revision: 29 $
$Date: 2008-12-31 16:47:56 +0000 (Wed, 31 Dec 2008) $
contact: codemaster2010 AT gmail DOT com

Copyright (c) 2007-2008 Michael J. Murray aka Starinnia of Lothar

This software is provided 'as-is', without any express or implied
warranty. In no event will the authors be held liable for any damages
arising from the use of this software.

Permission is granted to anyone to use this software for any purpose,
including commercial applications, and to alter it and redistribute it
freely, subject to the following restrictions:

1. The origin of this software must not be misrepresented; you must not
claim that you wrote the original software. If you use this software
in a product, an acknowledgment in the product documentation would be
appreciated but is not required.

2. Altered source versions must be plainly marked as such, and must not be
misrepresented as being the original software.

3. This notice may not be removed or altered from any source
distribution.
]]

local strformat = string.format
local strfind = string.find
local strsplit = strsplit

local Alabaster, Dusky, Golden, Violet, Silvery, Nether, Azure
local Burnt, Verdant, Sapphire, Ruby, Ebon, Icy, Indigo
local northrend, outlands, tier1, tier2, tier3, tier4, tier5, tier6

if GetLocale() == "enUS" or GetLocale() == "enGB" then
	alabaster = "Alabaster Pigment"
	dusky = "Dusky Pigment"
	golden = "Golden Pigment"
	violet = "Violet Pigment"
	silvery = "Silvery Pigment"
	nether = "Nether Pigment"
	azure = "Azure Pigment"
	emerald = "Emerald Pigment"
	burnt = "Burnt Pigment"
	verdant = "Verdant Pigment"
	sapphire = "Sapphire Pigment"
	ruby = "Ruby Pigment"
	ebon = "Ebon Pigment"
	icy = "Icy Pigment"
	indigo = "Indigo Pigment"
	northrend = "Northrend Herbs"
	outlands = "Outlands Herbs"
	tier1 = "Peacebloom, Silverleaf, Earthroot"
	tier2 = "Mageroyal, Briarthorn, Swiftthistle,\n Bruiseweed, Stranglekelp"
	tier3 = "Wild Steelbloom, Grave Moss, Kingsblood, Liferoot"
	tier4 = "Fadeleaf, Goldthorn, Khadgar's Whisker,\n Wintersbite"
	tier5 = "Firebloom, Purple Lotus, Arthas' Tears,\n Sungrass, Blindweed, Ghost Mushroom,\n Gromsblood"
	tier6 = "Golden Sansam, Dreamfoil, Mountain Silversage,\n Plaguebloom, Icecap"
elseif GetLocale() == "deDE" then
	alabaster = "Alabasterfarbene Pigmente"
	dusky = "Anthrazitfarbene Pigmente"
	golden = "Goldfarbene Pigmente"
	violet = "Violette Pigmente"
	silvery = "Silbrige Pigmente"
	nether = "Netherpigmente"
	azure = "Azurfarbene Pigmente"
	emerald = "Smaragdfarbene Pigmente"
	burnt = "Sienafarbene Pigmente"
	verdant = "Blattgrüne Pigmente"
	sapphire = "Saphirfarbene Pigmente"
	ruby = "Rubinfarbene Pigmente"
	ebon = "Rubinfarbene Pigmente"
	icy = "Eisblaue Pigmente"
	indigo = "Indigofarbene Pigmente"
	northrend = "Pflanzen Nordends"
	outlands = "Pflanzen der Scherbenwelt"
	tier1 = "Friedenblume, Silberblatt, Erdwurzel"
	tier2 = "Maguskönigskraut, Wilddornrose, Flitzdistel,\n Beulengras, Würgetang"
	tier3 = "Wild stahlblume, Grabmoos, Königsblut, Lebenswurz"
	tier4 = "Blassblatt, Golddorn, Khadgars Schnurrbart,\n Winterbiss"
	tier5 = "Feuerblüte	, Lila Lotus, Arthas' Tränen,\n Sonnengras, Blindkraut, Geisterpilz,\n Gromsblut"
	tier6 = "Goldener Sansam, Traumblatt, Bergsilbersalbei,\n Pestblüte, Eiskappe"
elseif GetLocale() == "esES" or GetLocale() == "esMX" then
	alabaster = "Pigmento de alabastro"
	dusky = "Pigmento oscurecido"
	golden = "Pigmento dorado"
	violet = "Pigmento violeta"
	silvery = "Pigmento de plata"
	nether = "Pigmento abisal"
	azure = "Pigmento azur"
	emerald = "Pigmento esmeralda"
	burnt = "Pigmento quemado"
	verdant = "Pigmento verdeante"
	sapphire = "Pigmento de zafiro"
	ruby = "Pigmento de rubí"
	ebon = "Pigmento de ébano"
	icy = "Pigmento helado"
	indigo = "Pigmento índigo"
	northrend = "Hierbas de Rasganorte"
	outlands = "Hierbas de Terrallende"
	tier1 = "Flor de paz, Hojaplata, Raíz de tierra"
	tier2 = "Marregal, Brezospina, Cardopresto,\n Hierba cardenal, Alga estranguladora"
	tier3 = "Acérita salvaje, Musgo de tumba, Sangrerregia\n, Vidarraíz"
	tier4 = "Pálida, Espina de oro, Mostacho de Khadgar,\n Ivernalia"
	tier5 = "Flor de Fuego, Loto cárdeno, Lágrimas de Arthas,\n Solea, Carolina, Champiñón fantasma,\n Gromsamguina"
	tier6 = "Sansam dorado, Hojasueño, Salviargenta de montaña,\n Flor de peste, Setelo"
elseif GetLocale() == "zhTW" then
    alabaster = "雪白顏料"
    dusky = "暮色顏料"
    golden = "金黃顏料"
    violet = "紫羅蘭顏料"
    silvery = "銀色顏料"
    nether = "虛空顏料"
    azure = "蒼藍顏料"
    emerald = "碧綠顏料"
    burnt = "焦褐顏料"
    verdant = "嫩綠顏料"
    sapphire = "天藍顏料"
    ruby = "晶紅顏料"
    ebon = "黑檀顏料"
    icy = "冰結顏料"
    indigo = "靛藍顏料"
    northrend = "北裂境草藥"
    outlands = "外域草藥"
    tier1 = "寧神花, 銀葉草, 地根草"
    tier2 = "魔皇草, 石南草, 雨燕草,\n 跌打草, 荊棘藻"
    tier3 = "野鋼花, 墓地苔, 皇血草, 活根草"
    tier4 = "枯葉草, 金棘草, 卡德加的鬍鬚,\n 冬刺草"
    tier5 = "火焰花, 紫蓮花, 阿薩斯之淚,\n 太陽草, 盲目草, 鬼魂菇,\n 格羅姆之血"
    tier6 = "黃金蔘, 夢葉草, 山鼠草,\n 瘟疫花, 冰蓋草"
elseif GetLocale() == "frFR" then
	alabaster = "Pigment albâtre"
	dusky = "Pigment crépusculaire"
	golden = "Pigment doré"
	violet = "Pigment violet"
	silvery = "	Pigment argenté"
	nether = "Pigment néantin"
	azure = "Pigment azur"
	emerald = "Pigment émeraude"
	burnt = "Pigment brûlé"
	verdant = "Pigment verdoyant"
	sapphire = "Pigment saphir"
	ruby = "Pigment rubis"
	ebon = "Pigment ébène"
	icy = "Pigment glacé"
	indigo = "Pigment indigo"
	northrend = "Herbes de Norfendre"
	outlands = "Herbes de l'Outreterre"
	tier1 = "Pacifique, Feuillargent, Terrestrine"
	tier2 = "Mage royal, Eglantine, Chardonnier,\n Doulourante, Etouffante"
	tier3 = "Aciérite sauvage, Tombeline, Sang-royal, Vietérule"
	tier4 = "Pâlerette, Dorépine, Moustache de Khadgar,\n Hivernale"
	tier5 = "Fleur de feu, Lotus pourpre, Larmes d'Arthas,\n Soleillette, Aveuglette, Champignon fantôme,\n Gromsang"
	tier6 = "Sansam doré, Feuillerêve, Fleur de peste,\n Sauge-argent des montagnes, Chapeglace"
elseif GetLocale() == "ruRU" then
	alabaster = "Алебастровый краситель"
	dusky = "Мглистый краситель"
	golden = "Золотой краситель"
	violet = "Фиалковый краситель"
	silvery = "Серебряный краситель"
	nether = "Краситель пустоты"
	azure = "Лазурный краситель"
	emerald = "Изумрудный краситель"
	burnt = "Жженый краситель"
	verdant = "Зеленый краситель"
	sapphire = "Сапфировый краситель"
	ruby = "Рубиновый краситель"
	ebon = "Эбеновый краситель"
	icy = "Ледяной краситель"
	indigo = "Краситель индиго"
	northrend = "Нордскола"
	outlands = "Запределья"
	tier1 = "Мироцвет, Сребролист, Землекорень"
	tier2 = "Магороза, Остротерн, Скорополох,\n Синячник, Удавник"
	tier3 = "Дикий сталецвет, Могильный мох, Королевская кровь,\n Корень жизни"
	tier4 = "Бледнолист, Златошип, Кадгаров ус,\n Морозник"
	tier5 = "Огнецвет, Лиловый лотос, Слезы Артаса,\n Солнечник, Пастушья сумка, Призрачная поганка,\n Кровь Грома"
	tier6 = "Золотой сансам, Снолист, Горный серебряный шалфей,\n Чумоцвет, Ледяной зев"
elseif GetLocale() == "koKR" then
	alabaster = "설화석고 안료"
	dusky = "거무스름한 안료"
	golden = "황금 안료"
	violet = "보랏빛 안료"
	silvery = "은빛 안료"
	nether = "황천 안료"
	azure = "하늘빛 안료"
	emerald = "에메랄드 안료"
	burnt = "태워 만든 안료"
	verdant = "푸른 안료"
	sapphire = "사파이어 안료"
	ruby = "루비 안료"
	ebon = "칠흑의 안료"
	icy = "얼음 안료"
	indigo = "쪽빛 안료"
	northrend = "노스렌드의 약초"
	outlands = "아웃랜드의 약초"
	tier1 = "평온초, 은엽수잎, 뱀뿌리"
	tier2 = "마법초 꽃잎, 찔레가시, 토끼엉겅퀴풀,\n 생채기풀, 갈래물풀"
	tier3 = "야생 철쭉, 무덤이끼, 왕꽃잎풀, 생명의 뿌리"
	tier4 = "미명초잎, 황금가시, 카드가의 수염,\n 겨울서리풀"
	tier5 = "화염초 꽃잎, 보라 연꽃, 아서스의 눈물,\n 태양풀, 실명초, 유령버섯,\n 그롬의 피"
	tier6 = "황금 산삼, 꿈풀, 은초롱이,\n 역병초 꽃잎, 얼음송이" 
else
	ChatFrame1:AddMessage("|cff33ff99MillHelp|r: No localization present for: " .. GetLocale() .. "! Help translate this addon if you can!")
	DisableAddOn("MillHelp")
	return
end

local commonPigments = {
	["2449"] = alabaster,
	["2447"] = alabaster,
	["765"] = alabaster,
	["785"] = dusky,
	["2450"] = dusky,
	["3820"] = dusky,
	["2452"] = dusky,
	["2453"] = dusky,
	["3357"] = golden,
	["3356"] = golden,
	["3355"] = golden,
	["3369"] = golden,
	["3358"] = emerald,
	["3821"] = emerald,
	["3819"] = emerald,
	["3818"] = emerald,
	["4625"] = violet,
	["8831"] = violet,
	["8836"] = violet,
	["8838"] = violet,
	["8839"] = violet,
	["8845"] = violet,
	["8846"] = violet,
	["13464"] = silvery,
	["13463"] = silvery,
	["13465"] = silvery,
	["13466"] = silvery,
	["13467"] = silvery,
	["22787"] = nether,
	["22790"] = nether,
	["22789"] = nether,
	["22792"] = nether,
	["22791"] = nether,
	["22785"] = nether,
	["22793"] = nether,
	["22786"] = nether,
	["36906"] = azure,
	["36905"] = azure,
	["36901"] = azure,
	["37921"] = azure,
	["36904"] = azure,
	["36903"] = azure,
	["36907"] = azure,
	["36902"] = azure,
}

local rarePigments = {
	["3356"] = burnt,
	["3357"] = burnt,
	["3369"] = burnt,
	["3355"] = burnt,
	["785"] = verdant,
	["2450"] = verdant,
	["2452"] = verdant,
	["2453"] = verdant,
	["3820"] = verdant,
	["13466"] = sapphire,
	["13465"] = sapphire,
	["13467"] = sapphire,
	["13464"] = sapphire,
	["13463"] = sapphire,
	["4625"] = ruby,
	["8831"] = ruby,
	["8836"] = ruby,
	["8838"] = ruby,
	["8839"] = ruby,
	["8845"] = ruby,
	["8846"] = ruby,
	["22791"] = ebon,
	["22793"] = ebon,
	["22792"] = ebon,
	["22790"] = ebon,
	["22789"] = ebon,
	["22786"] = ebon,
	["22785"] = ebon,
	["22787"] = ebon,
	["36903"] = icy,
	["36905"] = icy,
	["36906"] = icy,
	["36901"] = icy,
	["37921"] = icy,
	["36904"] = icy,
	["36907"] = icy,
	["36902"] = icy,
	["3358"] = indigo,
	["3821"] = indigo,
	["3819"] = indigo,
	["3818"] = indigo,
}

local commonInks = {
	["43120"] = tier5, --celestial ink
	["43124"] = outlands, --ethereal ink
	["43126"] = northrend, --ink of the sea
	["37101"] = tier1, --ivory ink
	["43118"] = tier4, --jadefire ink
	["43116"] = tier3, --lion's ink
	["39774"] = tier2, --midnight ink
	["39469"] = tier1, --moonglow ink
	["43122"] = tier6, --shimmering ink
}

local rareInks = {
	["43125"] = outlands, --darkflame ink
	["43117"] = tier3, --dawnstar ink
	["43121"] = tier5, --fiery ink
	["43115"] = tier2, --hunter's ink
	["43123"] = tier6, --ink of the sky
	["43119"] = tier4, --royal ink
	["43127"] = northrend, -- snowfall ink
}

local function AddMillingInfo(frame, itemLink)
	local _, _, itemString = strfind(itemLink, "^|c%x+|H(.+)|h%[.+%]")
	if itemString then
		local _, itemID = strsplit(":", itemString)
		if itemID then
			local cPigment, rPigment = commonPigments[itemID], rarePigments[itemID]
			local cInk, rInk = commonInks[itemID], rareInks[itemID]
			if cPigment then
				if MILLHELP_HEADER then
					frame:AddLine("|cffffffffMilling:|r")
				end
				frame:AddLine(strformat("|cffffffff%s|r", cPigment))
				if rPigment then
					frame:AddLine(strformat("|cff1eff00%s|r", rPigment))
				end
			elseif cInk then
				if MILLHELP_HEADER then
					frame:AddLine("|cffffffffFrom:|r")
				end
				frame:AddLine(strformat("|cffffffff%s|r", cInk))
			elseif rInk then
				if MILLHELP_HEADER then
					frame:AddLine("|cffffffffFrom:|r")
				end
				frame:AddLine(strformat("|cff1eff00%s|r", rInk))
			end
		end
	end
	
	frame:Show()
end

--fun with hooking!
local SetItem = GameTooltip:GetScript('OnTooltipSetItem')
GameTooltip:SetScript('OnTooltipSetItem', function(self, ...)
	if SetItem then
		SetItem(self, ...)
	end

	local itemLink = select(2, self:GetItem())
	if itemLink then
		AddMillingInfo(self, itemLink)
	end
end)

local SetItem = ItemRefTooltip:GetScript('OnTooltipSetItem')
ItemRefTooltip:SetScript('OnTooltipSetItem', function(self, ...)
	if SetItem then
		SetItem(self, ...)
	end

	local itemLink = select(2, self:GetItem())
	if itemLink then
		AddMillingInfo(self, itemLink)
	end
end)